@@ -15,7 +15,7 @@ def get_m2m_with_model(given_model):
 
 def is_buffer(value):
     if sys.version_info < (3, 0, 0):
-        return isinstance(value, buffer)
+        return isinstance(value, buffer)  # noqa
     else:
         return isinstance(value, memoryview)
 
