@@ -39,6 +39,8 @@ class DirtyFieldsMixin(object):
     def _as_dict(self, check_relationship, include_primary_key=True):
         all_field = {}
 
+        deferred_fields = self.get_deferred_fields()
+
         for field in self._meta.fields:
             if self.FIELDS_TO_CHECK and (field.get_attname() not in self.FIELDS_TO_CHECK):
                 continue
@@ -50,7 +52,7 @@ class DirtyFieldsMixin(object):
                 if not check_relationship:
                     continue
 
-            if field.get_attname() in self.get_deferred_fields():
+            if field.get_attname() in deferred_fields:
                 continue
 
             field_value = getattr(self, field.attname)
@@ -88,7 +90,6 @@ class DirtyFieldsMixin(object):
 
         return m2m_fields
 
-
     def get_dirty_fields(self, check_relationship=False, check_m2m=None, verbose=False):
         if self._state.adding:
             # If the object has not yet been saved in the database, all fields are considered dirty
@@ -133,14 +134,17 @@ def reset_state(sender, instance, **kwargs):
     # getting a `KeyError` when checking if a field is dirty or not
     update_fields = kwargs.pop('update_fields', {})
     new_state = instance._as_dict(check_relationship=True)
+    FIELDS_TO_CHECK = getattr(instance, "FIELDS_TO_CHECK", None)
     if update_fields:
         for field_name in update_fields:
             field = sender._meta.get_field(field_name)
+            if not FIELDS_TO_CHECK or \
+                    (field.get_attname() in FIELDS_TO_CHECK):
 
-            if field.get_attname() in instance.get_deferred_fields():
-                continue
+                if field.get_attname() in instance.get_deferred_fields():
+                    continue
 
-            instance._original_state[field.name] = new_state[field.name]
+                instance._original_state[field.name] = new_state[field.name]
 
     else:
         instance._original_state = new_state
