@@ -1,5 +1,3 @@
-import django
-
 from django.db import models
 from django.db.models.signals import pre_save
 from django.utils import timezone
@@ -99,7 +97,9 @@ class TestModelWithPreSaveSignal(DirtyFieldsMixin, models.Model):
             if 'specific_value' in instance.data:
                 instance.data_updated_on_presave = 'presave_value'
 
-pre_save.connect(TestModelWithPreSaveSignal.pre_save, sender=TestModelWithPreSaveSignal)
+
+pre_save.connect(TestModelWithPreSaveSignal.pre_save,
+                 sender=TestModelWithPreSaveSignal)
 
 
 class TestModelWithoutM2MCheck(DirtyFieldsMixin, models.Model):
@@ -125,9 +125,15 @@ class TestModelWithSpecifiedFields(DirtyFieldsMixin, models.Model):
     FIELDS_TO_CHECK = ['boolean1']
 
 
+class TestModelWithSpecifiedFieldsAndForeignKey(DirtyFieldsMixin, models.Model):
+    boolean1 = models.BooleanField(default=True)
+    boolean2 = models.BooleanField(default=True)
+    fk_field = models.OneToOneField(TestModel, null=True)
+    FIELDS_TO_CHECK = ['fk_field_id']
+
+
 class TestModelWithM2MAndSpecifiedFields(DirtyFieldsMixin, models.Model):
     m2m1 = models.ManyToManyField(TestModel)
     m2m2 = models.ManyToManyField(TestModel)
     ENABLE_M2M_CHECK = True
     FIELDS_TO_CHECK = ['m2m1']
-
